.. psprint documentation master file, created by
   sphinx-quickstart on Fri Jan 15 15:18:08 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to psprint's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   INSTALL
   configure
   usage
   source-code-doc

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

